@@ -53,6 +53,7 @@ class LocalShell(object):
                 stdin=stdin_arg,
                 stdout=stdout_arg,
                 stderr=stderr_arg,
+                bufsize=0,
                 **self._subprocess_args(command, *args, **kwargs)
             )
             
@@ -132,8 +133,6 @@ class LocalProcess(object):
         
     def stdin_write(self, value):
         self._process_stdin.write(value)
-        # TODO: find a more elegant way of handling buffering that seems to be introduced in Python 3
-        self._process_stdin.flush()
         
     def send_signal(self, signal):
         self._subprocess.send_signal(signal)
